@@ -1,4 +1,4 @@
-# Copyright 2020 QuantumBlack Visual Analytics Limited
+# Copyright 2021 QuantumBlack Visual Analytics Limited
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -38,11 +38,11 @@ from kedro.pipeline.decorators import _func_full_name
 
 try:
     from memory_profiler import memory_usage
-except ImportError as error:
+except ImportError as exc:
     raise ImportError(
-        "{}: `pip install kedro[profilers]` to get the required "
-        "memory profiler dependencies.".format(error)
-    )
+        f"{exc}: `pip install kedro[profilers]` to get the required "
+        "memory profiler dependencies."
+    ) from exc
 
 
 def mem_profile(func: Callable) -> Callable:
